@@ -28,6 +28,7 @@
 import os
 import sys
 import re
+import shutil
 import select
 import time
 import signal
@@ -105,6 +106,8 @@ class SubmitClient:
       self.clientData['importObjects']       = {}
       self.clientData['exportObjects']       = {}
       self.clientData['closePendingObjects'] = []
+      self.clientData['filesToRemove']       = []
+      self.clientData['emptyFilesToRemove']  = []
 
       signal.signal(signal.SIGINT,self.handleTerminationSignal)
       signal.signal(signal.SIGHUP,self.handleTerminationSignal)
@@ -526,8 +529,6 @@ class SubmitClient:
       self.clientData['enteredCommand'] = self.commandParser.getEnteredCommand()
       enteredCommandArguments = self.commandParser.getEnteredCommandArguments()
 
-      filesToRemove      = []
-      emptyFilesToRemove = []
       self.clientData['jobPath'] = os.path.join(os.getcwd(),localJobId)
       if not os.path.isdir(self.clientData['jobPath']):
          os.mkdir(self.clientData['jobPath'])
@@ -651,11 +652,15 @@ class SubmitClient:
             fpAppScript.write(appScript)
             fpAppScript.close()
             os.chmod(appScriptPath,stat.S_IRWXU|stat.S_IRGRP|stat.S_IXGRP|stat.S_IROTH|stat.S_IXOTH)
+            self.clientData['filesToRemove'].append(appScriptPath)
          else:
             log("could not open %s for writing" % (appScriptPath))
             exitCode = 1
          del localBatchAppScript
 
+         stdFile = os.path.join(self.clientData['jobPath'],instanceId,"%s_%s.stderr" % (localJobId,instanceId))
+         self.clientData['emptyFilesToRemove'].append(stdFile)
+
       nInstances      = instance
       executeInstance = nInstances+1
 
@@ -681,6 +686,7 @@ class SubmitClient:
          fpBatchScript.write(batchScript)
          fpBatchScript.close()
          os.chmod(batchScriptPath,stat.S_IRWXU|stat.S_IRGRP|stat.S_IXGRP|stat.S_IROTH|stat.S_IXOTH)
+         self.clientData['filesToRemove'].append(batchScriptPath)
       else:
          log("could not open %s for writing" % (batchScriptPath))
          exitCode = 1
@@ -688,7 +694,7 @@ class SubmitClient:
       enteredCommand = self.commandParser.getEnteredCommand()
 
       stdFile = "%s.stderr" % (localJobId)
-      emptyFilesToRemove.append(stdFile)
+      self.clientData['emptyFilesToRemove'].append(stdFile)
 
       self.clientData['startDate']      = time.strftime("%a %b %d %X %Z %Y")
       self.clientData['localStartTime'] = time.time()
@@ -714,16 +720,6 @@ class SubmitClient:
          self.jobScanner.start()
 
 
-#     for fileToRemove in filesToRemove:
-#        if(os.path.exists(fileToRemove)):
-#           os.remove(fileToRemove)
-
-#     for fileToRemove in emptyFilesToRemove:
-#        if(os.path.exists(fileToRemove)):
-#           if(os.path.getsize(fileToRemove) == 0):
-#              os.remove(fileToRemove)
-
-
    def startLocalExecute(self):
       self.clientData['localStartTime'] = time.time()
       commandArguments = self.commandParser.getEnteredCommandArguments()
@@ -780,6 +776,13 @@ class SubmitClient:
             cpuTime        = jobStatistic['userTime']+jobStatistic['sysTime']
             elapsedRunTime = jobStatistic['elapsedRunTime']
 
+            workDirectoryName = os.path.join(self.clientData['jobPath'],'work')
+            if os.path.isdir(workDirectoryName):
+               shutil.rmtree(workDirectoryName,True)
+            workDirectoryName = os.path.join(self.clientData['jobPath'],'scratch')
+            if os.path.isdir(workDirectoryName):
+               shutil.rmtree(workDirectoryName,True)
+
             self.serverConnection.postServerMessage('localMetrics %d %d %f %f\n' % (instance,exitCode,cpuTime,elapsedRunTime))
             del jobStatistic
 
@@ -788,6 +791,15 @@ class SubmitClient:
       if self.clientData['isParametric']:
          self.finishLocalParametric()
 
+      for fileToRemove in self.clientData['filesToRemove']:
+         if(os.path.exists(fileToRemove)):
+            os.remove(fileToRemove)
+
+      for fileToRemove in self.clientData['emptyFilesToRemove']:
+         if(os.path.exists(fileToRemove)):
+            if(os.path.getsize(fileToRemove) == 0):
+               os.remove(fileToRemove)
+
 
    def scanLocalOutputFile(self,
                            outputFileObject):
@@ -1121,7 +1133,11 @@ class SubmitClient:
                if self.jobScanner.processInput():
                   self.jobScanner.finish()
                   self.jobScanner = None
-                  sys.stdout.write("Simulations complete. Results are stored in directory %s\n" % (self.clientData['jobPath']))
+                  if self.clientData['localExecution']:
+                     resultsPath = self.clientData['jobPath']
+                  else:
+                     resultsPath = os.path.join(self.clientData['jobPath'],"%08d" % (self.serverData['jobId']))
+                  sys.stdout.write("Simulations complete. Results are stored in directory %s\n" % resultsPath)
             elif self.clientData['readyToExit']:
                self.exit()
 
@@ -1134,7 +1150,11 @@ class SubmitClient:
                if self.jobScanner.processInput():
                   self.jobScanner.finish()
                   self.jobScanner = None
-                  sys.stdout.write("Simulations complete. Results are stored in directory %s\n" % (self.clientData['jobPath']))
+                  if self.clientData['localExecution']:
+                     resultsPath = self.clientData['jobPath']
+                  else:
+                     resultsPath = os.path.join(self.clientData['jobPath'],"%08d" % (self.serverData['jobId']))
+                  sys.stdout.write("Simulations complete. Results are stored in directory %s\n" % resultsPath)
                   os.kill(os.getpid(),signal.SIGINT)
             else:
                self.readFile(readyReader)
